@@ -179,13 +179,11 @@ def _show_missing_code_main(config: Config, session: Session) -> None:
     features, scenarios, steps = parse_feature_files(config.option.features)
 
     for item in session.items:
-        scenario = getattr(item.obj, "__scenario__", None)
-        if scenario:
+        if scenario := getattr(item.obj, "__scenario__", None):
             if scenario in scenarios:
                 scenarios.remove(scenario)
             for step in scenario.steps:
-                fixturedefs = _find_step_fixturedef(fm, item, step=step)
-                if fixturedefs:
+                if _find_step_fixturedef(fm, item, step=step):
                     try:
                         steps.remove(step)
                     except ValueError:
